OC.L10N.register(
    "settings",
    {
    "Wrong password" : "Грешна парола",
    "No user supplied" : "Липсва потребителско име",
    "Authentication error" : "Възникна проблем с идентификацията",
    "Wrong admin recovery password. Please check the password and try again." : "Грешна администраторска парола за възстановяване. Моля, проверете паролата и опитайте отново.",
    "Backend doesn't support password change, but the user's encryption key was successfully updated." : "Сървърът не позволява смяна на паролата, но потребителския ключ за криптиране беше успешно обновен.",
    "Unable to change password" : "Неуспешна смяна на паролата.",
    "Couldn't send reset email. Please contact your administrator." : "Изпращането на електронна поща е неуспешно. Моля, свържете се с вашия администратор.",
    "Federated Cloud Sharing" : "Федеративно споделяне през облака",
    "Group already exists." : "Групата вече съществува.",
    "Unable to add group." : "Неуспешно добавяне на група.",
    "Unable to delete group." : "Неуспешно изтриване на група",
    "log-level out of allowed range" : "Ниво на проследяване \\(log-level\\) e извън допустимия обхват",
    "Saved" : "Запаметяване",
    "test email settings" : "проверка на настройките на електронна поща",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Настъпи проблем при изпращането на имейла. Моля, провери настройките.  (Грешка: %s)",
    "Email sent" : "Имейлът е изпратен",
    "You need to set your user email before being able to send test emails." : "Трябва да зададете своя имейл преди да можете да изпращате тестови имейли.",
    "Invalid mail address" : "невалиден адрес на електронна поща",
    "A user with that name already exists." : "Потребител с това име вече съществува",
    "Unable to create user." : "Неуспешно създаване на потребител.",
    "Your %s account was created" : "Вашия %s профил бе създаден",
    "Unable to delete user." : "Неуспешно изтриване на потребител.",
    "Forbidden" : "Забранено",
    "Invalid user" : "Невалиден протребител",
    "Unable to change mail address" : "Неуспешна промяна на адрес на електронна поща",
    "Your full name has been changed." : "Вашето пълно име е променено.",
    "Unable to change full name" : "Неуспешна промяна на пълното име.",
    "__language_name__" : "Български",
    "Language changed" : "Езикът е променен",
    "Invalid request" : "Невалидна заявка",
    "Admins can't remove themself from the admin group" : "Администраторите не могат да премахват себе си от групата \"admin\".",
    "Unknown user" : "Непознат потребител",
    "Couldn't remove app." : "Неуспешно премахване на приложението.",
    "All" : "Всички",
    "Enabled" : "Включено",
    "Not enabled" : "Изключено",
    "No apps found for your version" : "Няма намерени приложения за вашата версия",
    "Please wait...." : "Моля, изчакайте....",
    "Error while disabling app" : "Грешка при изключването на приложението",
    "Disable" : "Изключване",
    "Enable" : "Включване",
    "Error while enabling app" : "Грешка при включване на приложението",
    "Updating...." : "Обновяване...",
    "Error while updating app" : "Грешка при обновяване на приложението.",
    "Updated" : "Обновено",
    "Uninstalling ...." : "Премахване ...",
    "Error while uninstalling app" : "Грешка при премахването на приложението",
    "Uninstall" : "Премахване",
    "Are you really sure you want add \"{domain}\" as trusted domain?" : "Сигурен/на ли сте, че искате \"{domain}\"  да бъде добавен като сигурен домейн?",
    "Add trusted domain" : "Добавяне на сигурен домейн",
    "Valid until {date}" : "Далидна до {date}",
    "Delete" : "Изтриване",
    "Sending..." : "Изпращане...",
    "Select a profile picture" : "Избиране на профилна снимка",
    "Very weak password" : "Много слаба парола",
    "Weak password" : "Слаба парола",
    "So-so password" : "Не особено добра парола",
    "Good password" : "Добра парола",
    "Strong password" : "Сигурна парола",
    "Groups" : "Групи",
    "Unable to delete {objName}" : "Неуспешно изтриване на {objName}.",
    "A valid group name must be provided" : "Очаква се валидно име на група",
    "deleted {groupName}" : "{groupName} е изтрита",
    "undo" : "възстановяване",
    "never" : "никога",
    "deleted {userName}" : "{userName}  е изтрит",
    "add group" : "добавяне на група",
    "enabled" : "включен",
    "disabled" : "изключен",
    "no group" : "няма група",
    "Changing the password will result in data loss, because data recovery is not available for this user" : "Промяна на паролата ще доведе до загуба на данни, защото не е налично възстановяване за този потребител.",
    "A valid username must be provided" : "Трябва да бъде зададено валидно потребителско име",
    "A valid password must be provided" : "Трябва да бъде зададена валидна парола",
    "A valid email must be provided" : "Трябва да бъде зададена валидна електронна поща",
    "Hey there,<br><br>just letting you know that you now have an %s account.<br><br>Your username: %s<br>Access it: <a href=\"%s\">%s</a><br><br>" : "Здрасти,<br><br>Само да ти кажа, че имаш %s профил<br><br> Потребителя ти е: %s<br>Достъпи го: <a href=\"%s\">%s</a><br><br>",
    "Cheers!" : "Поздрави!",
    "Hey there,\n\njust letting you know that you now have an %s account.\n\nYour username: %s\nAccess it: %s\n\n" : "Здрасти,\n\nСамо да ти кажа, че имаш %s профил.\n\nПотребителя ти е: %s\nДостъпи го: %s\n",
    "Forum" : "Форум",
    "Developer documentation" : "Документация за разработчици",
    "Documentation:" : "Документация:",
    "Report a bug" : "Докладване на бъг",
    "Show description …" : "Покажи описание ...",
    "Hide description …" : "Скрии описание ...",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Това приложение не може да бъде инсталирано, защото следните зависимости не са удовлетворени:",
    "Enable only for specific groups" : "Включи само за определени групи",
    "Uninstall App" : "Премахни Приложението",
    "Cron" : "Крон",
    "Last cron job execution: %s." : "Последно изпълнение на cron задача: %s.",
    "Last cron job execution: %s. Something seems wrong." : "Последно изпълнение на cron задача: %s. Нещо не е както трябва",
    "Cron was not executed yet!" : "Cron oще не е изпълнен!",
    "Open documentation" : "Отвори документацията",
    "Execute one task with each page loaded" : "Изпълни по едно задание с всяка заредена страница.",
    "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." : "cron.php е регистриран към webcron да се свързва с cron.php всеки 15 минути по http.",
    "Use system's cron service to call the cron.php file every 15 minutes." : "Изполвай системната cron service, за връзка с cron.php файла всеки 15 минути.",
    "Common Name" : "Познато Име",
    "Valid until" : "Валиден до",
    "Issued By" : "Издаден От",
    "Valid until %s" : "Валиден до %s",
    "Import root certificate" : "Импортиране на основен сертификат",
    "Enable encryption" : "Активиране на криптиране",
    "Sharing" : "Споделяне",
    "Allow apps to use the Share API" : "Разреши приложенията да използват Share API.",
    "Allow users to share via link" : "Разреши потребителите да споделят с връзка",
    "Allow public uploads" : "Разреши общодостъпно качване",
    "Enforce password protection" : "Изискай защита с парола.",
    "Set default expiration date" : "Заложи дата на изтичане по подразбиране",
    "Allow users to send mail notification for shared files" : "Разреши потребителите да изпращат имейл уведомления за споделени файлове.",
    "Expire after " : "Изтечи след",
    "days" : "дена",
    "Enforce expiration date" : "Изисквай дата на изтичане",
    "Allow resharing" : "Разреши пресподеляне.",
    "Restrict users to only share with users in their groups" : "Ограничи потребителите, така че да могат да споделят само с други потребители в своите групи.",
    "Allow users to send mail notification for shared files to other users" : "Разреши потребителите да изпращат уведомителни писма за споделени файлове към други потребители.",
    "Exclude groups from sharing" : "Забрани групи да споделят",
    "These groups will still be able to receive shares, but not to initiate them." : "Тези групи ще могат да получават споделения, но няма да могат самите те да споделят.",
    "Everything (fatal issues, errors, warnings, info, debug)" : "Всичко (фатални проблеми, грешки, предупреждения, информация, дебъгване)",
    "Info, warnings, errors and fatal issues" : "информация, предупреждения, грешки и фатални проблеми",
    "Warnings, errors and fatal issues" : "Предупреждения, грешки и фатални проблеми",
    "Errors and fatal issues" : "Грешки и фатални проблеми",
    "Fatal issues only" : "Само фатални проблеми",
    "Log" : "Лог",
    "The logfile is bigger than 100 MB. Downloading it may take some time!" : "Log файла е по-голям от 100 MB. Изтеглянето му може да отнеме време!",
    "None" : "Няма",
    "Login" : "Вход",
    "Plain" : "Обикновен",
    "NT LAN Manager" : "NT LAN Manager",
    "This is used for sending out notifications." : "Това се използва за изпращане на уведомления.",
    "Send mode" : "Режим на изпращане",
    "Encryption" : "Криптиране",
    "From address" : "От адрес",
    "mail" : "поща",
    "Authentication method" : "Метод за отризиране",
    "Authentication required" : "Нужна е идентификация",
    "Server address" : "Адрес на сървъра",
    "Port" : "Порт",
    "Credentials" : "Потр. име и парола",
    "SMTP Username" : "SMTP Потребителско Име",
    "SMTP Password" : "SMTP Парола",
    "Store credentials" : "Запазвай креденциите",
    "Test email settings" : "Настройки на проверяващия имейл",
    "Send email" : "Изпрати имейл",
    "Security & setup warnings" : "Предупреждения за сигурност и настройки",
    "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "PHP е настроен да премахва inline doc блокове. Това ще направи няколко основни приложения недостъпни.",
    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Това може да се дължи на кеш/акселератор като Zend OPache или eAccelerator.",
    "The PHP module 'fileinfo' is missing. We strongly recommend to enable this module to get best results with mime-type detection." : "PHP модулът 'fileinfo' липсва. Силно препоръчваме този модъл да бъде добавен, за да бъдат постигнати най-добри резултати при mime-type откриването.",
    "System locale can not be set to a one which supports UTF-8." : "Системните настройки за местоположение не могат да бъдат промени на такива, подържащи UTF-8.",
    "This means that there might be problems with certain characters in file names." : "Това означва, че може да има проблеми с определини символи в имената на файловете.",
    "We strongly suggest installing the required packages on your system to support one of the following locales: %s." : "Силно препоръчваме инсталиране на необходимите паките на системата, за поддръжка на следните местоположения: %s.",
    "If your installation is not installed in the root of the domain and uses system cron, there can be issues with the URL generation. To avoid these problems, please set the \"overwrite.cli.url\" option in your config.php file to the webroot path of your installation (Suggested: \"%s\")" : "Ако инсталацията не е в основата на вашия домейн и използва системния cron, могат да възникнат проблеми с генерирането на URLи. За избягване на тези проблеми, моля настройте <code>overwrite.cli.url</code> опцията в config.php файла с мрежовия път към вашята инсталация (Вероятно : \\\"%s\\\")",
    "SQLite is used as database. For larger installations we recommend to switch to a different database backend." : "SQLite е използваната база данни. За по-големи инсталации Ви препоръчваме да изберете друг сървър за бази данни.",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Особено, когато използвате клиент за работен плот за синхронизация, използването на SQLite e непрепоръчително.",
    "It was not possible to execute the cronjob via CLI. The following technical errors have appeared:" : "Не бе възможно да изпълним cron задачата през команден интерфейс. Следните технически грешки се появиха:",
    "How to do backups" : "Как се правят резервни копия",
    "Advanced monitoring" : "Разширено наблюдение",
    "Performance tuning" : "Настройване на производителност",
    "Improving the config.php" : "Подобряване на config.php",
    "Theming" : "Промяна на облика",
    "Get the apps to sync your files" : "Изтегли програми за синхронизиране на файловете ти",
    "Desktop client" : "Клиент за настолен компютър",
    "Android app" : "Андроид приложение",
    "iOS app" : "iOS приложение",
    "Show First Run Wizard again" : "Покажи Настройките за Първоначално Зареждане отново",
    "Profile picture" : "Аватар",
    "Upload new" : "Качи нов",
    "Remove image" : "Премахни изображението",
    "Cancel" : "Отказ",
    "Full name" : "Пълно име",
    "No display name set" : "Няма настроено екранно име",
    "Email" : "Имейл",
    "Your email address" : "Твоят имейл адрес",
    "No email address set" : "Няма настроен адрес на електронна поща",
    "You are member of the following groups:" : "Ти си член на следните групи:",
    "Password" : "Парола",
    "Unable to change your password" : "Неуспешна промяна на паролата.",
    "Current password" : "Текуща парола",
    "New password" : "Нова парола",
    "Change password" : "Промяна на паролата",
    "Language" : "Език",
    "Help translate" : "Помогни с превода",
    "Unlimited" : "Неограничено",
    "Developed by the {communityopen}ownCloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}." : "Разработен от {communityopen}ownCloud общността {linkclose}, {githubopen}изходящия код{linkclose} е лицензиран под {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose}.",
    "Name" : "Име",
    "Username" : "Потребителско Име",
    "Done" : "Завършен",
    "Version" : "Версия",
    "Personal" : "Лично",
    "Admin" : "Админ",
    "Error" : "Грешка",
    "Show storage location" : "Покажи място за запис",
    "Show last log in" : "Покажи последно вписване",
    "Send email to new user" : "Изпращай писмо към нов потребител",
    "Show email address" : "Покажи адреса на електронната поща",
    "E-Mail" : "Електронна поща",
    "Create" : "Създаване",
    "Admin Recovery Password" : "Възстановяване на Администраторска Парола",
    "Enter the recovery password in order to recover the users files during password change" : "Въведи паролата за възстановяване, за да възстановиш файловете на потребителите при промяна на паролата.",
    "Add Group" : "Добави Група",
    "Group" : "Група",
    "Everyone" : "Всички",
    "Admins" : "Администратори",
    "Default Quota" : "Квота по подразбиране",
    "Please enter storage quota (ex: \"512 MB\" or \"12 GB\")" : "Моля, въведи квота за заделено място (пр. \"512 MB\" или \"12 GB\")",
    "Other" : "Друга...",
    "Full Name" : "Пълно Име",
    "Group Admin for" : "Групов администратор за",
    "Quota" : "Квота",
    "Storage Location" : "Място за Запис",
    "Last Login" : "Последно Вписване",
    "change full name" : "промени пълното име",
    "set new password" : "сложи нова парола",
    "change email address" : "Смени адреса на елетронната поща",
    "Default" : "По подразбиране",
    "The new password can not be the same as the previous one" : "Новата парола не може да бъде същата като предишната",
    "Change" : "Промени",
    "Share" : "Споделяне",
    "APCu" : "APCu",
    "Official" : "Официално",
    "Approved" : "Одобрено",
    "The app will be downloaded from the app store" : "Приложението ще бъде изтеглено от магазина за приложения",
    "App update" : "Актуализиране на приложението",
    "Experimental" : "Експериментално",
    "Migration in progress. Please wait until the migration is finished" : "Миграцията е в ход. Моля, изчакайте, докато мигрирането завърши",
    "Disconnect" : "Прекъсване",
    "User documentation" : "Потребителска документация",
    "Administrator documentation" : "Документация за администратора",
    "Online documentation" : "Онлайн документация",
    "Commercial support" : "Търговска подкрепа",
    "by %s" : "от %s",
    "Admin documentation" : "Документация за администратора",
    "Visit website" : "Посетете уебсайт",
    "Server-side encryption" : "Криптиране от страна на сървъра",
    "Enable server-side encryption" : "Включи криптиране от страна на сървъра",
    "Start migration" : "Стартирайте мигрирането",
    "Allow users to share file via social media" : "Позволете на потребителите да споделят файлове чрез социални медии",
    "What to log" : "Какво да се записва",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Email server" : "Имейл сървър",
    "Encryption alone does not guarantee security of the system. Please see ownCloud documentation for more information about how the encryption app works, and the supported use cases." : "Криптирането не гарантира сигурността на системата. Моля, вижте ownCloud документацията за повече информация, за това как функционира приложението за шифроване и за поддържаните случаи на използване.",
    "System Status" : "Статус на системата",
    "Tips & tricks" : "Съвети и трикове",
    "Domain" : "Домейн",
    "Add Domain" : "Добави домейн",
    "Select from Files" : "Изберете от Файловете",
    "png or jpg, max. 20 MB" : "png или jpg, макс. 20 MB",
    "Choose as profile picture" : "Избиране на профилна снимка",
    "Change email" : "Промяна на имейла",
    "Set email" : "Задайте имейл",
    "You are using %s of %s" : "Вие използвате %s от %s",
    "Sessions" : "Сесии",
    "Browser" : "Браузър",
    "Most recent activity" : "Последна активност",
    "App passwords" : "Пароли за приложения",
    "App name" : "Име на приложението",
    "Create new app password" : "Създаване на нова парола за приложение",
    "Error: this app cannot be enabled because it makes the server unstable" : "Грешка: това приложение не може да бъде активирано, защото прави сървъра нестабилен",
    "Error: could not disable broken app" : "Грешка: не може да се деактивира счупеното приложение",
    "Error while disabling broken app" : "Грешка при деактивиране на счупено приложение",
    "CORS" : "CORS",
    "Apps Management" : "Управление на приложения",
    "Show enabled apps" : "Показване на активираните приложения",
    "Show disabled apps" : "Показване на изключените приложения",
    "SSL Root Certificates" : "SSL root сертификати",
    "Allow sharing with groups" : "Разрешаване на споделянето с групи",
    "User ID" : "Потребителско ID",
    "Email address" : "Имейл адрес",
    "Picture provided by original account" : "Снимка, предоставена от оригиналния профил",
    "For password recovery and notifications" : "За възстановяване на паролата и известия",
    "You are using %s of %s (%s %%)" : "Вие използвате %s от %s (%s %%)",
    "%s password changed successfully" : "%s паролата е сменена успешно",
    "Official apps are developed by and within the ownCloud community. They offer functionality central to ownCloud and are ready for production use." : "Официалните приложения се разработват от и в рамките на ownCloud общността. Те предлагат допълнителна функционалност на ownCloud и са готови за производствена употреба.",
    "Approved apps are developed by trusted developers and have passed a cursory security check. They are actively maintained in an open code repository and their maintainers deem them to be stable for casual to normal use." : "Одобрените приложения се разработват от надеждни програмисти и преминават проверка за сигурност. Те се поддържат активно в хранилище с отворен код и техните поддържащи ги считат за стабилни при случайно до нормално използване.",
    "This app is not checked for security issues and is new or known to be unstable. Install at your own risk." : "Това приложение не е проверено за проблеми със сигурността, то е ново или е известно, че е нестабилно. Инсталирайте на свой собствен риск.",
    "No apps found for {query}" : "Няма намерени приложения за {query}",
    "Migration started …" : "Мигрирането започна ...",
    "%s-licensed" : "%s-лицензирано",
    "Be aware that encryption always increases the file size." : "Имайте предвид, че шифроването винаги увеличава размера на файла.",
    "This is the final warning: Do you really want to enable encryption?" : "Това е последно предупреждение: Наистина ли искате да активирате шифроването?",
    "Select default encryption module:" : "Изберете модул за шифроване по подразбиране:",
    "Download logfile (%s)" : "Изтегляне на доклад (1%s)",
    "No Domains." : "Няма домейни.",
    "Are you sure you want to remove this domain?" : "Наистина ли искате да премахнете този домейн?",
    "Add" : "Добави",
    "You've linked these apps." : "Свързахте тези приложения.",
    "An app password is a passcode that gives an app or device permissions to access your %s account." : "Паролата за приложение е парола, която дава на дадено приложение или устройство разрешение за достъп до вашия %s профил.",
    "No panels for this section." : "Няма панели за този раздел.",
    "cURL is using an outdated %s version (%s). Please update your operating system or features such as %s will not work reliably." : "cURL използва неактуална %s версия (%s). Моля, актуализирайте операционната си система или функции, като %s няма да работят надеждно.",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Приложението е активирано, но трябва да бъде актуализирано. Ще бъдете пренасочени към страницата за актуализиране за 5 секунди.",
    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "Възникна грешка. Моля, качете ASCII-кодиран PEM сертификат.",
    "Empty app name is not allowed." : "Не е разрешено името на приложението да е празно.",
    "Failed to change the email address." : "Промяната на имейл адреса не бе успешна.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Винаги е добре да създавате редовни резервни копия на данните си, в случай на криптиране не забравяйте да архивирате криптиращите ключове заедно с вашите данни.",
    "Allow username autocompletion in share dialog. If this is disabled the full username needs to be entered." : "Разреши автоматичното попълване на потребителското име в диалоговия прозорец за споделяне. Ако това е забранено, ще трябва ръчно да се въвежда пълното потребителско име.",
    "The config file is read only. Please adjust your setup by editing the config file manually." : "Конфигурационният файл е с права само за четене. Моля, коригирайте настройката си, като ръчно редактирате конфигурационния файл.",
    "All checks passed." : "Всички проверки са преминати.",
    "Use the credentials below to configure your app or device." : "Използвайте данните по-долу, за да конфигурирате приложението или устройството си.",
    "Email has been changed successfully." : "Имейлът е променен успешно."
},
"nplurals=2; plural=(n != 1);");
